#ifndef _OPTIONS_FONT_H__
#define _OPTIONS_FONT_H__ 1

void options_font(Evas_Object *opbox, Evas_Object *term);

#endif
